QOSIC_BASE_URL = "https://qosic.net:8443"
# MTN
MTN_PAYMENT_PATH = "/QosicBridge/user/requestpayment"
MTN_PAYMENT_STATUS_PATH = "/QosicBridge/user/gettransactionstatus"
MTN_PREFIXES = ["51", "52", "53", "61", "62", "66", "67", "69", "90", "91", "96", "97"]
MTN_REFUND_PATH = "/QosicBridge/user/refund"
# MOOV
MOOV_PAYMENT_PATH = "/QosicBridge/user/requestpaymentmv"
MOOV_PREFIXES = ["55", "60", "63", "64", "65", "68", "94", "95", "98", "99"]
